/*******************************************************************************
 * Copyright 2012-2013 Jonathan Wienss, Michael Stein, Roland Ewald
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 *   http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/
package alesia.componentrating.activeRanking

/**
 * Generates a ranking (e.g.: winner, 2nd place, ..., looser) for each selected match-up.
 * The match-ups are selected by a <code>MatchUpSelector</code>,
 * which in turn is based on <code>MatchQuality</code>.
 *
 * @see MatchUpSelector
 *
 * @author Jonathan Wienss
 */
abstract class RankingComparator(useVirtualPlayerTeamWeighting: Boolean = false) extends ActiveRankingComponent {

  val components: Set[String] = getComponents

  /** Get available components. */
  def getComponents: Set[String]

  /** Generate a comparison of component teams. */
  def apply(): List[Set[String]]
}
